# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmwasm/wasm/v1/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmwasm/wasm/v1/types.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x11\x61mino/amino.proto\"V\n\x0f\x41\x63\x63\x65ssTypeParam\x12=\n\x05value\x18\x01 \x01(\x0e\x32\x1c.cosmwasm.wasm.v1.AccessTypeB\x10\xf2\xde\x1f\x0cyaml:\"value\":\x04\x98\xa0\x1f\x01\"\x8c\x01\n\x0c\x41\x63\x63\x65ssConfig\x12G\n\npermission\x18\x01 \x01(\x0e\x32\x1c.cosmwasm.wasm.v1.AccessTypeB\x15\xf2\xde\x1f\x11yaml:\"permission\"\x12\'\n\taddresses\x18\x03 \x03(\tB\x14\xf2\xde\x1f\x10yaml:\"addresses\":\x04\x98\xa0\x1f\x01J\x04\x08\x02\x10\x03\"\xe3\x01\n\x06Params\x12\x62\n\x12\x63ode_upload_access\x18\x01 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigB&\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xf2\xde\x1f\x19yaml:\"code_upload_access\"\x12o\n\x1einstantiate_default_permission\x18\x02 \x01(\x0e\x32\x1c.cosmwasm.wasm.v1.AccessTypeB)\xf2\xde\x1f%yaml:\"instantiate_default_permission\":\x04\x98\xa0\x1f\x00\"\x81\x01\n\x08\x43odeInfo\x12\x11\n\tcode_hash\x18\x01 \x01(\x0c\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\x12\x45\n\x12instantiate_config\x18\x05 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"\x90\x02\n\x0c\x43ontractInfo\x12\x1b\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\x12\r\n\x05\x61\x64min\x18\x03 \x01(\t\x12\r\n\x05label\x18\x04 \x01(\t\x12\x35\n\x07\x63reated\x18\x05 \x01(\x0b\x32$.cosmwasm.wasm.v1.AbsoluteTxPosition\x12\"\n\x0bibc_port_id\x18\x06 \x01(\tB\r\xe2\xde\x1f\tIBCPortID\x12S\n\textension\x18\x07 \x01(\x0b\x32\x14.google.protobuf.AnyB*\xca\xb4-&cosmwasm.wasm.v1.ContractInfoExtension:\x04\xe8\xa0\x1f\x01\"\xda\x01\n\x18\x43ontractCodeHistoryEntry\x12\x45\n\toperation\x18\x01 \x01(\x0e\x32\x32.cosmwasm.wasm.v1.ContractCodeHistoryOperationType\x12\x1b\n\x07\x63ode_id\x18\x02 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\x35\n\x07updated\x18\x03 \x01(\x0b\x32$.cosmwasm.wasm.v1.AbsoluteTxPosition\x12#\n\x03msg\x18\x04 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\"<\n\x12\x41\x62soluteTxPosition\x12\x14\n\x0c\x62lock_height\x18\x01 \x01(\x04\x12\x10\n\x08tx_index\x18\x02 \x01(\x04\"Y\n\x05Model\x12\x41\n\x03key\x18\x01 \x01(\x0c\x42\x34\xfa\xde\x1f\x30github.com/cometbft/cometbft/libs/bytes.HexBytes\x12\r\n\x05value\x18\x02 \x01(\x0c*\xf6\x01\n\nAccessType\x12\x36\n\x17\x41\x43\x43\x45SS_TYPE_UNSPECIFIED\x10\x00\x1a\x19\x8a\x9d \x15\x41\x63\x63\x65ssTypeUnspecified\x12,\n\x12\x41\x43\x43\x45SS_TYPE_NOBODY\x10\x01\x1a\x14\x8a\x9d \x10\x41\x63\x63\x65ssTypeNobody\x12\x32\n\x15\x41\x43\x43\x45SS_TYPE_EVERYBODY\x10\x03\x1a\x17\x8a\x9d \x13\x41\x63\x63\x65ssTypeEverybody\x12>\n\x1c\x41\x43\x43\x45SS_TYPE_ANY_OF_ADDRESSES\x10\x04\x1a\x1c\x8a\x9d \x18\x41\x63\x63\x65ssTypeAnyOfAddresses\x1a\x08\x88\xa3\x1e\x00\xa8\xa4\x1e\x00\"\x04\x08\x02\x10\x02*\xa6\x03\n ContractCodeHistoryOperationType\x12\x65\n0CONTRACT_CODE_HISTORY_OPERATION_TYPE_UNSPECIFIED\x10\x00\x1a/\x8a\x9d +ContractCodeHistoryOperationTypeUnspecified\x12W\n)CONTRACT_CODE_HISTORY_OPERATION_TYPE_INIT\x10\x01\x1a(\x8a\x9d $ContractCodeHistoryOperationTypeInit\x12]\n,CONTRACT_CODE_HISTORY_OPERATION_TYPE_MIGRATE\x10\x02\x1a+\x8a\x9d \'ContractCodeHistoryOperationTypeMigrate\x12]\n,CONTRACT_CODE_HISTORY_OPERATION_TYPE_GENESIS\x10\x03\x1a+\x8a\x9d \'ContractCodeHistoryOperationTypeGenesis\x1a\x04\x88\xa3\x1e\x00\x42\x30Z&github.com/CosmWasm/wasmd/x/wasm/types\xc8\xe1\x1e\x00\xa8\xe2\x1e\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmwasm.wasm.v1.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z&github.com/CosmWasm/wasmd/x/wasm/types\310\341\036\000\250\342\036\001'
  _ACCESSTYPE._options = None
  _ACCESSTYPE._serialized_options = b'\210\243\036\000\250\244\036\000'
  _ACCESSTYPE.values_by_name["ACCESS_TYPE_UNSPECIFIED"]._options = None
  _ACCESSTYPE.values_by_name["ACCESS_TYPE_UNSPECIFIED"]._serialized_options = b'\212\235 \025AccessTypeUnspecified'
  _ACCESSTYPE.values_by_name["ACCESS_TYPE_NOBODY"]._options = None
  _ACCESSTYPE.values_by_name["ACCESS_TYPE_NOBODY"]._serialized_options = b'\212\235 \020AccessTypeNobody'
  _ACCESSTYPE.values_by_name["ACCESS_TYPE_EVERYBODY"]._options = None
  _ACCESSTYPE.values_by_name["ACCESS_TYPE_EVERYBODY"]._serialized_options = b'\212\235 \023AccessTypeEverybody'
  _ACCESSTYPE.values_by_name["ACCESS_TYPE_ANY_OF_ADDRESSES"]._options = None
  _ACCESSTYPE.values_by_name["ACCESS_TYPE_ANY_OF_ADDRESSES"]._serialized_options = b'\212\235 \030AccessTypeAnyOfAddresses'
  _CONTRACTCODEHISTORYOPERATIONTYPE._options = None
  _CONTRACTCODEHISTORYOPERATIONTYPE._serialized_options = b'\210\243\036\000'
  _CONTRACTCODEHISTORYOPERATIONTYPE.values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_UNSPECIFIED"]._options = None
  _CONTRACTCODEHISTORYOPERATIONTYPE.values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_UNSPECIFIED"]._serialized_options = b'\212\235 +ContractCodeHistoryOperationTypeUnspecified'
  _CONTRACTCODEHISTORYOPERATIONTYPE.values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_INIT"]._options = None
  _CONTRACTCODEHISTORYOPERATIONTYPE.values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_INIT"]._serialized_options = b'\212\235 $ContractCodeHistoryOperationTypeInit'
  _CONTRACTCODEHISTORYOPERATIONTYPE.values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_MIGRATE"]._options = None
  _CONTRACTCODEHISTORYOPERATIONTYPE.values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_MIGRATE"]._serialized_options = b'\212\235 \'ContractCodeHistoryOperationTypeMigrate'
  _CONTRACTCODEHISTORYOPERATIONTYPE.values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_GENESIS"]._options = None
  _CONTRACTCODEHISTORYOPERATIONTYPE.values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_GENESIS"]._serialized_options = b'\212\235 \'ContractCodeHistoryOperationTypeGenesis'
  _ACCESSTYPEPARAM.fields_by_name['value']._options = None
  _ACCESSTYPEPARAM.fields_by_name['value']._serialized_options = b'\362\336\037\014yaml:\"value\"'
  _ACCESSTYPEPARAM._options = None
  _ACCESSTYPEPARAM._serialized_options = b'\230\240\037\001'
  _ACCESSCONFIG.fields_by_name['permission']._options = None
  _ACCESSCONFIG.fields_by_name['permission']._serialized_options = b'\362\336\037\021yaml:\"permission\"'
  _ACCESSCONFIG.fields_by_name['addresses']._options = None
  _ACCESSCONFIG.fields_by_name['addresses']._serialized_options = b'\362\336\037\020yaml:\"addresses\"'
  _ACCESSCONFIG._options = None
  _ACCESSCONFIG._serialized_options = b'\230\240\037\001'
  _PARAMS.fields_by_name['code_upload_access']._options = None
  _PARAMS.fields_by_name['code_upload_access']._serialized_options = b'\310\336\037\000\250\347\260*\001\362\336\037\031yaml:\"code_upload_access\"'
  _PARAMS.fields_by_name['instantiate_default_permission']._options = None
  _PARAMS.fields_by_name['instantiate_default_permission']._serialized_options = b'\362\336\037%yaml:\"instantiate_default_permission\"'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\230\240\037\000'
  _CODEINFO.fields_by_name['instantiate_config']._options = None
  _CODEINFO.fields_by_name['instantiate_config']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _CONTRACTINFO.fields_by_name['code_id']._options = None
  _CONTRACTINFO.fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _CONTRACTINFO.fields_by_name['ibc_port_id']._options = None
  _CONTRACTINFO.fields_by_name['ibc_port_id']._serialized_options = b'\342\336\037\tIBCPortID'
  _CONTRACTINFO.fields_by_name['extension']._options = None
  _CONTRACTINFO.fields_by_name['extension']._serialized_options = b'\312\264-&cosmwasm.wasm.v1.ContractInfoExtension'
  _CONTRACTINFO._options = None
  _CONTRACTINFO._serialized_options = b'\350\240\037\001'
  _CONTRACTCODEHISTORYENTRY.fields_by_name['code_id']._options = None
  _CONTRACTCODEHISTORYENTRY.fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _CONTRACTCODEHISTORYENTRY.fields_by_name['msg']._options = None
  _CONTRACTCODEHISTORYENTRY.fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _MODEL.fields_by_name['key']._options = None
  _MODEL.fields_by_name['key']._serialized_options = b'\372\336\0370github.com/cometbft/cometbft/libs/bytes.HexBytes'
  _ACCESSTYPE._serialized_start=1388
  _ACCESSTYPE._serialized_end=1634
  _CONTRACTCODEHISTORYOPERATIONTYPE._serialized_start=1637
  _CONTRACTCODEHISTORYOPERATIONTYPE._serialized_end=2059
  _ACCESSTYPEPARAM._serialized_start=145
  _ACCESSTYPEPARAM._serialized_end=231
  _ACCESSCONFIG._serialized_start=234
  _ACCESSCONFIG._serialized_end=374
  _PARAMS._serialized_start=377
  _PARAMS._serialized_end=604
  _CODEINFO._serialized_start=607
  _CODEINFO._serialized_end=736
  _CONTRACTINFO._serialized_start=739
  _CONTRACTINFO._serialized_end=1011
  _CONTRACTCODEHISTORYENTRY._serialized_start=1014
  _CONTRACTCODEHISTORYENTRY._serialized_end=1232
  _ABSOLUTETXPOSITION._serialized_start=1234
  _ABSOLUTETXPOSITION._serialized_end=1294
  _MODEL._serialized_start=1296
  _MODEL._serialized_end=1385
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/channel/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cibc/core/channel/v1/tx.proto\x12\x13ibc.core.channel.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fibc/core/client/v1/client.proto\x1a!ibc/core/channel/v1/channel.proto\x1a\x17\x63osmos/msg/v1/msg.proto\"\x7f\n\x12MsgChannelOpenInit\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x33\n\x07\x63hannel\x18\x02 \x01(\x0b\x32\x1c.ibc.core.channel.v1.ChannelB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"A\n\x1aMsgChannelOpenInitResponse\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"\x89\x02\n\x11MsgChannelOpenTry\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x1f\n\x13previous_channel_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x33\n\x07\x63hannel\x18\x03 \x01(\x0b\x32\x1c.ibc.core.channel.v1.ChannelB\x04\xc8\xde\x1f\x00\x12\x1c\n\x14\x63ounterparty_version\x18\x04 \x01(\t\x12\x12\n\nproof_init\x18\x05 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x07 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"@\n\x19MsgChannelOpenTryResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\"\xe7\x01\n\x11MsgChannelOpenAck\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x1f\n\x17\x63ounterparty_channel_id\x18\x03 \x01(\t\x12\x1c\n\x14\x63ounterparty_version\x18\x04 \x01(\t\x12\x11\n\tproof_try\x18\x05 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x07 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1b\n\x19MsgChannelOpenAckResponse\"\xac\x01\n\x15MsgChannelOpenConfirm\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x11\n\tproof_ack\x18\x03 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1f\n\x1dMsgChannelOpenConfirmResponse\"_\n\x13MsgChannelCloseInit\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1d\n\x1bMsgChannelCloseInitResponse\"\xae\x01\n\x16MsgChannelCloseConfirm\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x12\n\nproof_init\x18\x03 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\" \n\x1eMsgChannelCloseConfirmResponse\"\xb9\x01\n\rMsgRecvPacket\x12\x31\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x12\x18\n\x10proof_commitment\x18\x02 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x04 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"V\n\x15MsgRecvPacketResponse\x12\x37\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultType:\x04\x88\xa0\x1f\x00\"\xd2\x01\n\nMsgTimeout\x12\x31\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x12\x18\n\x10proof_unreceived\x18\x02 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x1a\n\x12next_sequence_recv\x18\x04 \x01(\x04\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"S\n\x12MsgTimeoutResponse\x12\x37\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultType:\x04\x88\xa0\x1f\x00\"\xee\x01\n\x11MsgTimeoutOnClose\x12\x31\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x12\x18\n\x10proof_unreceived\x18\x02 \x01(\x0c\x12\x13\n\x0bproof_close\x18\x03 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x1a\n\x12next_sequence_recv\x18\x05 \x01(\x04\x12\x0e\n\x06signer\x18\x06 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"Z\n\x19MsgTimeoutOnCloseResponse\x12\x37\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultType:\x04\x88\xa0\x1f\x00\"\xd2\x01\n\x12MsgAcknowledgement\x12\x31\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x12\x17\n\x0f\x61\x63knowledgement\x18\x02 \x01(\x0c\x12\x13\n\x0bproof_acked\x18\x03 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"[\n\x1aMsgAcknowledgementResponse\x12\x37\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultType:\x04\x88\xa0\x1f\x00*\xa9\x01\n\x12ResponseResultType\x12\x35\n RESPONSE_RESULT_TYPE_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUNSPECIFIED\x12\'\n\x19RESPONSE_RESULT_TYPE_NOOP\x10\x01\x1a\x08\x8a\x9d \x04NOOP\x12-\n\x1cRESPONSE_RESULT_TYPE_SUCCESS\x10\x02\x1a\x0b\x8a\x9d \x07SUCCESS\x1a\x04\x88\xa3\x1e\x00\x32\xb6\x08\n\x03Msg\x12k\n\x0f\x43hannelOpenInit\x12\'.ibc.core.channel.v1.MsgChannelOpenInit\x1a/.ibc.core.channel.v1.MsgChannelOpenInitResponse\x12h\n\x0e\x43hannelOpenTry\x12&.ibc.core.channel.v1.MsgChannelOpenTry\x1a..ibc.core.channel.v1.MsgChannelOpenTryResponse\x12h\n\x0e\x43hannelOpenAck\x12&.ibc.core.channel.v1.MsgChannelOpenAck\x1a..ibc.core.channel.v1.MsgChannelOpenAckResponse\x12t\n\x12\x43hannelOpenConfirm\x12*.ibc.core.channel.v1.MsgChannelOpenConfirm\x1a\x32.ibc.core.channel.v1.MsgChannelOpenConfirmResponse\x12n\n\x10\x43hannelCloseInit\x12(.ibc.core.channel.v1.MsgChannelCloseInit\x1a\x30.ibc.core.channel.v1.MsgChannelCloseInitResponse\x12w\n\x13\x43hannelCloseConfirm\x12+.ibc.core.channel.v1.MsgChannelCloseConfirm\x1a\x33.ibc.core.channel.v1.MsgChannelCloseConfirmResponse\x12\\\n\nRecvPacket\x12\".ibc.core.channel.v1.MsgRecvPacket\x1a*.ibc.core.channel.v1.MsgRecvPacketResponse\x12S\n\x07Timeout\x12\x1f.ibc.core.channel.v1.MsgTimeout\x1a\'.ibc.core.channel.v1.MsgTimeoutResponse\x12h\n\x0eTimeoutOnClose\x12&.ibc.core.channel.v1.MsgTimeoutOnClose\x1a..ibc.core.channel.v1.MsgTimeoutOnCloseResponse\x12k\n\x0f\x41\x63knowledgement\x12\'.ibc.core.channel.v1.MsgAcknowledgement\x1a/.ibc.core.channel.v1.MsgAcknowledgementResponse\x1a\x05\x80\xe7\xb0*\x01\x42;Z9github.com/cosmos/ibc-go/v7/modules/core/04-channel/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.channel.v1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z9github.com/cosmos/ibc-go/v7/modules/core/04-channel/types'
  _RESPONSERESULTTYPE._options = None
  _RESPONSERESULTTYPE._serialized_options = b'\210\243\036\000'
  _RESPONSERESULTTYPE.values_by_name["RESPONSE_RESULT_TYPE_UNSPECIFIED"]._options = None
  _RESPONSERESULTTYPE.values_by_name["RESPONSE_RESULT_TYPE_UNSPECIFIED"]._serialized_options = b'\212\235 \013UNSPECIFIED'
  _RESPONSERESULTTYPE.values_by_name["RESPONSE_RESULT_TYPE_NOOP"]._options = None
  _RESPONSERESULTTYPE.values_by_name["RESPONSE_RESULT_TYPE_NOOP"]._serialized_options = b'\212\235 \004NOOP'
  _RESPONSERESULTTYPE.values_by_name["RESPONSE_RESULT_TYPE_SUCCESS"]._options = None
  _RESPONSERESULTTYPE.values_by_name["RESPONSE_RESULT_TYPE_SUCCESS"]._serialized_options = b'\212\235 \007SUCCESS'
  _MSGCHANNELOPENINIT.fields_by_name['channel']._options = None
  _MSGCHANNELOPENINIT.fields_by_name['channel']._serialized_options = b'\310\336\037\000'
  _MSGCHANNELOPENINIT._options = None
  _MSGCHANNELOPENINIT._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGCHANNELOPENTRY.fields_by_name['previous_channel_id']._options = None
  _MSGCHANNELOPENTRY.fields_by_name['previous_channel_id']._serialized_options = b'\030\001'
  _MSGCHANNELOPENTRY.fields_by_name['channel']._options = None
  _MSGCHANNELOPENTRY.fields_by_name['channel']._serialized_options = b'\310\336\037\000'
  _MSGCHANNELOPENTRY.fields_by_name['proof_height']._options = None
  _MSGCHANNELOPENTRY.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _MSGCHANNELOPENTRY._options = None
  _MSGCHANNELOPENTRY._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGCHANNELOPENACK.fields_by_name['proof_height']._options = None
  _MSGCHANNELOPENACK.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _MSGCHANNELOPENACK._options = None
  _MSGCHANNELOPENACK._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGCHANNELOPENCONFIRM.fields_by_name['proof_height']._options = None
  _MSGCHANNELOPENCONFIRM.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _MSGCHANNELOPENCONFIRM._options = None
  _MSGCHANNELOPENCONFIRM._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGCHANNELCLOSEINIT._options = None
  _MSGCHANNELCLOSEINIT._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGCHANNELCLOSECONFIRM.fields_by_name['proof_height']._options = None
  _MSGCHANNELCLOSECONFIRM.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _MSGCHANNELCLOSECONFIRM._options = None
  _MSGCHANNELCLOSECONFIRM._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGRECVPACKET.fields_by_name['packet']._options = None
  _MSGRECVPACKET.fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _MSGRECVPACKET.fields_by_name['proof_height']._options = None
  _MSGRECVPACKET.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _MSGRECVPACKET._options = None
  _MSGRECVPACKET._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGRECVPACKETRESPONSE._options = None
  _MSGRECVPACKETRESPONSE._serialized_options = b'\210\240\037\000'
  _MSGTIMEOUT.fields_by_name['packet']._options = None
  _MSGTIMEOUT.fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _MSGTIMEOUT.fields_by_name['proof_height']._options = None
  _MSGTIMEOUT.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _MSGTIMEOUT._options = None
  _MSGTIMEOUT._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGTIMEOUTRESPONSE._options = None
  _MSGTIMEOUTRESPONSE._serialized_options = b'\210\240\037\000'
  _MSGTIMEOUTONCLOSE.fields_by_name['packet']._options = None
  _MSGTIMEOUTONCLOSE.fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _MSGTIMEOUTONCLOSE.fields_by_name['proof_height']._options = None
  _MSGTIMEOUTONCLOSE.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _MSGTIMEOUTONCLOSE._options = None
  _MSGTIMEOUTONCLOSE._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGTIMEOUTONCLOSERESPONSE._options = None
  _MSGTIMEOUTONCLOSERESPONSE._serialized_options = b'\210\240\037\000'
  _MSGACKNOWLEDGEMENT.fields_by_name['packet']._options = None
  _MSGACKNOWLEDGEMENT.fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _MSGACKNOWLEDGEMENT.fields_by_name['proof_height']._options = None
  _MSGACKNOWLEDGEMENT.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _MSGACKNOWLEDGEMENT._options = None
  _MSGACKNOWLEDGEMENT._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGACKNOWLEDGEMENTRESPONSE._options = None
  _MSGACKNOWLEDGEMENTRESPONSE._serialized_options = b'\210\240\037\000'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _RESPONSERESULTTYPE._serialized_start=2722
  _RESPONSERESULTTYPE._serialized_end=2891
  _MSGCHANNELOPENINIT._serialized_start=168
  _MSGCHANNELOPENINIT._serialized_end=295
  _MSGCHANNELOPENINITRESPONSE._serialized_start=297
  _MSGCHANNELOPENINITRESPONSE._serialized_end=362
  _MSGCHANNELOPENTRY._serialized_start=365
  _MSGCHANNELOPENTRY._serialized_end=630
  _MSGCHANNELOPENTRYRESPONSE._serialized_start=632
  _MSGCHANNELOPENTRYRESPONSE._serialized_end=696
  _MSGCHANNELOPENACK._serialized_start=699
  _MSGCHANNELOPENACK._serialized_end=930
  _MSGCHANNELOPENACKRESPONSE._serialized_start=932
  _MSGCHANNELOPENACKRESPONSE._serialized_end=959
  _MSGCHANNELOPENCONFIRM._serialized_start=962
  _MSGCHANNELOPENCONFIRM._serialized_end=1134
  _MSGCHANNELOPENCONFIRMRESPONSE._serialized_start=1136
  _MSGCHANNELOPENCONFIRMRESPONSE._serialized_end=1167
  _MSGCHANNELCLOSEINIT._serialized_start=1169
  _MSGCHANNELCLOSEINIT._serialized_end=1264
  _MSGCHANNELCLOSEINITRESPONSE._serialized_start=1266
  _MSGCHANNELCLOSEINITRESPONSE._serialized_end=1295
  _MSGCHANNELCLOSECONFIRM._serialized_start=1298
  _MSGCHANNELCLOSECONFIRM._serialized_end=1472
  _MSGCHANNELCLOSECONFIRMRESPONSE._serialized_start=1474
  _MSGCHANNELCLOSECONFIRMRESPONSE._serialized_end=1506
  _MSGRECVPACKET._serialized_start=1509
  _MSGRECVPACKET._serialized_end=1694
  _MSGRECVPACKETRESPONSE._serialized_start=1696
  _MSGRECVPACKETRESPONSE._serialized_end=1782
  _MSGTIMEOUT._serialized_start=1785
  _MSGTIMEOUT._serialized_end=1995
  _MSGTIMEOUTRESPONSE._serialized_start=1997
  _MSGTIMEOUTRESPONSE._serialized_end=2080
  _MSGTIMEOUTONCLOSE._serialized_start=2083
  _MSGTIMEOUTONCLOSE._serialized_end=2321
  _MSGTIMEOUTONCLOSERESPONSE._serialized_start=2323
  _MSGTIMEOUTONCLOSERESPONSE._serialized_end=2413
  _MSGACKNOWLEDGEMENT._serialized_start=2416
  _MSGACKNOWLEDGEMENT._serialized_end=2626
  _MSGACKNOWLEDGEMENTRESPONSE._serialized_start=2628
  _MSGACKNOWLEDGEMENTRESPONSE._serialized_end=2719
  _MSG._serialized_start=2894
  _MSG._serialized_end=3972
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/fee/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ibc.applications.fee.v1 import fee_pb2 as ibc_dot_applications_dot_fee_dot_v1_dot_fee__pb2
from ibc.applications.fee.v1 import genesis_pb2 as ibc_dot_applications_dot_fee_dot_v1_dot_genesis__pb2
from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#ibc/applications/fee/v1/query.proto\x12\x17ibc.applications.fee.v1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a!ibc/applications/fee/v1/fee.proto\x1a%ibc/applications/fee/v1/genesis.proto\x1a!ibc/core/channel/v1/channel.proto\"s\n\x1fQueryIncentivizedPacketsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\x12\x14\n\x0cquery_height\x18\x02 \x01(\x04\"\xb2\x01\n QueryIncentivizedPacketsResponse\x12Q\n\x14incentivized_packets\x18\x01 \x03(\x0b\x32-.ibc.applications.fee.v1.IdentifiedPacketFeesB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"n\n\x1eQueryIncentivizedPacketRequest\x12\x36\n\tpacket_id\x18\x01 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\x04\xc8\xde\x1f\x00\x12\x14\n\x0cquery_height\x18\x02 \x01(\x04\"s\n\x1fQueryIncentivizedPacketResponse\x12P\n\x13incentivized_packet\x18\x01 \x01(\x0b\x32-.ibc.applications.fee.v1.IdentifiedPacketFeesB\x04\xc8\xde\x1f\x00\"\xa2\x01\n)QueryIncentivizedPacketsForChannelRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\x12\x0f\n\x07port_id\x18\x02 \x01(\t\x12\x12\n\nchannel_id\x18\x03 \x01(\t\x12\x14\n\x0cquery_height\x18\x04 \x01(\x04\"\xb6\x01\n*QueryIncentivizedPacketsForChannelResponse\x12K\n\x14incentivized_packets\x18\x01 \x03(\x0b\x32-.ibc.applications.fee.v1.IdentifiedPacketFees\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"S\n\x19QueryTotalRecvFeesRequest\x12\x36\n\tpacket_id\x18\x01 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\x04\xc8\xde\x1f\x00\"|\n\x1aQueryTotalRecvFeesResponse\x12^\n\trecv_fees\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"R\n\x18QueryTotalAckFeesRequest\x12\x36\n\tpacket_id\x18\x01 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\x04\xc8\xde\x1f\x00\"z\n\x19QueryTotalAckFeesResponse\x12]\n\x08\x61\x63k_fees\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"V\n\x1cQueryTotalTimeoutFeesRequest\x12\x36\n\tpacket_id\x18\x01 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\x04\xc8\xde\x1f\x00\"\x82\x01\n\x1dQueryTotalTimeoutFeesResponse\x12\x61\n\x0ctimeout_fees\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"8\n\x11QueryPayeeRequest\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\x0f\n\x07relayer\x18\x02 \x01(\t\"+\n\x12QueryPayeeResponse\x12\x15\n\rpayee_address\x18\x01 \x01(\t\"D\n\x1dQueryCounterpartyPayeeRequest\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\x0f\n\x07relayer\x18\x02 \x01(\t\"<\n\x1eQueryCounterpartyPayeeResponse\x12\x1a\n\x12\x63ounterparty_payee\x18\x01 \x01(\t\"r\n\x1eQueryFeeEnabledChannelsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\x12\x14\n\x0cquery_height\x18\x02 \x01(\x04\"\xae\x01\n\x1fQueryFeeEnabledChannelsResponse\x12N\n\x14\x66\x65\x65_enabled_channels\x18\x01 \x03(\x0b\x32*.ibc.applications.fee.v1.FeeEnabledChannelB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"D\n\x1dQueryFeeEnabledChannelRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\"5\n\x1eQueryFeeEnabledChannelResponse\x12\x13\n\x0b\x66\x65\x65_enabled\x18\x01 \x01(\x08\x32\xe6\x11\n\x05Query\x12\xb9\x01\n\x13IncentivizedPackets\x12\x38.ibc.applications.fee.v1.QueryIncentivizedPacketsRequest\x1a\x39.ibc.applications.fee.v1.QueryIncentivizedPacketsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/ibc/apps/fee/v1/incentivized_packets\x12\x8f\x02\n\x12IncentivizedPacket\x12\x37.ibc.applications.fee.v1.QueryIncentivizedPacketRequest\x1a\x38.ibc.applications.fee.v1.QueryIncentivizedPacketResponse\"\x85\x01\x82\xd3\xe4\x93\x02\x7f\x12}/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/incentivized_packet\x12\xfd\x01\n\x1dIncentivizedPacketsForChannel\x12\x42.ibc.applications.fee.v1.QueryIncentivizedPacketsForChannelRequest\x1a\x43.ibc.applications.fee.v1.QueryIncentivizedPacketsForChannelResponse\"S\x82\xd3\xe4\x93\x02M\x12K/ibc/apps/fee/v1/channels/{channel_id}/ports/{port_id}/incentivized_packets\x12\xfc\x01\n\rTotalRecvFees\x12\x32.ibc.applications.fee.v1.QueryTotalRecvFeesRequest\x1a\x33.ibc.applications.fee.v1.QueryTotalRecvFeesResponse\"\x81\x01\x82\xd3\xe4\x93\x02{\x12y/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/total_recv_fees\x12\xf8\x01\n\x0cTotalAckFees\x12\x31.ibc.applications.fee.v1.QueryTotalAckFeesRequest\x1a\x32.ibc.applications.fee.v1.QueryTotalAckFeesResponse\"\x80\x01\x82\xd3\xe4\x93\x02z\x12x/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/total_ack_fees\x12\x88\x02\n\x10TotalTimeoutFees\x12\x35.ibc.applications.fee.v1.QueryTotalTimeoutFeesRequest\x1a\x36.ibc.applications.fee.v1.QueryTotalTimeoutFeesResponse\"\x84\x01\x82\xd3\xe4\x93\x02~\x12|/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/total_timeout_fees\x12\xa9\x01\n\x05Payee\x12*.ibc.applications.fee.v1.QueryPayeeRequest\x1a+.ibc.applications.fee.v1.QueryPayeeResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/ibc/apps/fee/v1/channels/{channel_id}/relayers/{relayer}/payee\x12\xda\x01\n\x11\x43ounterpartyPayee\x12\x36.ibc.applications.fee.v1.QueryCounterpartyPayeeRequest\x1a\x37.ibc.applications.fee.v1.QueryCounterpartyPayeeResponse\"T\x82\xd3\xe4\x93\x02N\x12L/ibc/apps/fee/v1/channels/{channel_id}/relayers/{relayer}/counterparty_payee\x12\xad\x01\n\x12\x46\x65\x65\x45nabledChannels\x12\x37.ibc.applications.fee.v1.QueryFeeEnabledChannelsRequest\x1a\x38.ibc.applications.fee.v1.QueryFeeEnabledChannelsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/ibc/apps/fee/v1/fee_enabled\x12\xd0\x01\n\x11\x46\x65\x65\x45nabledChannel\x12\x36.ibc.applications.fee.v1.QueryFeeEnabledChannelRequest\x1a\x37.ibc.applications.fee.v1.QueryFeeEnabledChannelResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/ibc/apps/fee/v1/channels/{channel_id}/ports/{port_id}/fee_enabledB7Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.fee.v1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/types'
  _QUERYINCENTIVIZEDPACKETSRESPONSE.fields_by_name['incentivized_packets']._options = None
  _QUERYINCENTIVIZEDPACKETSRESPONSE.fields_by_name['incentivized_packets']._serialized_options = b'\310\336\037\000'
  _QUERYINCENTIVIZEDPACKETREQUEST.fields_by_name['packet_id']._options = None
  _QUERYINCENTIVIZEDPACKETREQUEST.fields_by_name['packet_id']._serialized_options = b'\310\336\037\000'
  _QUERYINCENTIVIZEDPACKETRESPONSE.fields_by_name['incentivized_packet']._options = None
  _QUERYINCENTIVIZEDPACKETRESPONSE.fields_by_name['incentivized_packet']._serialized_options = b'\310\336\037\000'
  _QUERYTOTALRECVFEESREQUEST.fields_by_name['packet_id']._options = None
  _QUERYTOTALRECVFEESREQUEST.fields_by_name['packet_id']._serialized_options = b'\310\336\037\000'
  _QUERYTOTALRECVFEESRESPONSE.fields_by_name['recv_fees']._options = None
  _QUERYTOTALRECVFEESRESPONSE.fields_by_name['recv_fees']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _QUERYTOTALACKFEESREQUEST.fields_by_name['packet_id']._options = None
  _QUERYTOTALACKFEESREQUEST.fields_by_name['packet_id']._serialized_options = b'\310\336\037\000'
  _QUERYTOTALACKFEESRESPONSE.fields_by_name['ack_fees']._options = None
  _QUERYTOTALACKFEESRESPONSE.fields_by_name['ack_fees']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _QUERYTOTALTIMEOUTFEESREQUEST.fields_by_name['packet_id']._options = None
  _QUERYTOTALTIMEOUTFEESREQUEST.fields_by_name['packet_id']._serialized_options = b'\310\336\037\000'
  _QUERYTOTALTIMEOUTFEESRESPONSE.fields_by_name['timeout_fees']._options = None
  _QUERYTOTALTIMEOUTFEESRESPONSE.fields_by_name['timeout_fees']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _QUERYFEEENABLEDCHANNELSRESPONSE.fields_by_name['fee_enabled_channels']._options = None
  _QUERYFEEENABLEDCHANNELSRESPONSE.fields_by_name['fee_enabled_channels']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['IncentivizedPackets']._options = None
  _QUERY.methods_by_name['IncentivizedPackets']._serialized_options = b'\202\323\344\223\002\'\022%/ibc/apps/fee/v1/incentivized_packets'
  _QUERY.methods_by_name['IncentivizedPacket']._options = None
  _QUERY.methods_by_name['IncentivizedPacket']._serialized_options = b'\202\323\344\223\002\177\022}/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/incentivized_packet'
  _QUERY.methods_by_name['IncentivizedPacketsForChannel']._options = None
  _QUERY.methods_by_name['IncentivizedPacketsForChannel']._serialized_options = b'\202\323\344\223\002M\022K/ibc/apps/fee/v1/channels/{channel_id}/ports/{port_id}/incentivized_packets'
  _QUERY.methods_by_name['TotalRecvFees']._options = None
  _QUERY.methods_by_name['TotalRecvFees']._serialized_options = b'\202\323\344\223\002{\022y/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/total_recv_fees'
  _QUERY.methods_by_name['TotalAckFees']._options = None
  _QUERY.methods_by_name['TotalAckFees']._serialized_options = b'\202\323\344\223\002z\022x/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/total_ack_fees'
  _QUERY.methods_by_name['TotalTimeoutFees']._options = None
  _QUERY.methods_by_name['TotalTimeoutFees']._serialized_options = b'\202\323\344\223\002~\022|/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/total_timeout_fees'
  _QUERY.methods_by_name['Payee']._options = None
  _QUERY.methods_by_name['Payee']._serialized_options = b'\202\323\344\223\002A\022?/ibc/apps/fee/v1/channels/{channel_id}/relayers/{relayer}/payee'
  _QUERY.methods_by_name['CounterpartyPayee']._options = None
  _QUERY.methods_by_name['CounterpartyPayee']._serialized_options = b'\202\323\344\223\002N\022L/ibc/apps/fee/v1/channels/{channel_id}/relayers/{relayer}/counterparty_payee'
  _QUERY.methods_by_name['FeeEnabledChannels']._options = None
  _QUERY.methods_by_name['FeeEnabledChannels']._serialized_options = b'\202\323\344\223\002\036\022\034/ibc/apps/fee/v1/fee_enabled'
  _QUERY.methods_by_name['FeeEnabledChannel']._options = None
  _QUERY.methods_by_name['FeeEnabledChannel']._serialized_options = b'\202\323\344\223\002D\022B/ibc/apps/fee/v1/channels/{channel_id}/ports/{port_id}/fee_enabled'
  _QUERYINCENTIVIZEDPACKETSREQUEST._serialized_start=301
  _QUERYINCENTIVIZEDPACKETSREQUEST._serialized_end=416
  _QUERYINCENTIVIZEDPACKETSRESPONSE._serialized_start=419
  _QUERYINCENTIVIZEDPACKETSRESPONSE._serialized_end=597
  _QUERYINCENTIVIZEDPACKETREQUEST._serialized_start=599
  _QUERYINCENTIVIZEDPACKETREQUEST._serialized_end=709
  _QUERYINCENTIVIZEDPACKETRESPONSE._serialized_start=711
  _QUERYINCENTIVIZEDPACKETRESPONSE._serialized_end=826
  _QUERYINCENTIVIZEDPACKETSFORCHANNELREQUEST._serialized_start=829
  _QUERYINCENTIVIZEDPACKETSFORCHANNELREQUEST._serialized_end=991
  _QUERYINCENTIVIZEDPACKETSFORCHANNELRESPONSE._serialized_start=994
  _QUERYINCENTIVIZEDPACKETSFORCHANNELRESPONSE._serialized_end=1176
  _QUERYTOTALRECVFEESREQUEST._serialized_start=1178
  _QUERYTOTALRECVFEESREQUEST._serialized_end=1261
  _QUERYTOTALRECVFEESRESPONSE._serialized_start=1263
  _QUERYTOTALRECVFEESRESPONSE._serialized_end=1387
  _QUERYTOTALACKFEESREQUEST._serialized_start=1389
  _QUERYTOTALACKFEESREQUEST._serialized_end=1471
  _QUERYTOTALACKFEESRESPONSE._serialized_start=1473
  _QUERYTOTALACKFEESRESPONSE._serialized_end=1595
  _QUERYTOTALTIMEOUTFEESREQUEST._serialized_start=1597
  _QUERYTOTALTIMEOUTFEESREQUEST._serialized_end=1683
  _QUERYTOTALTIMEOUTFEESRESPONSE._serialized_start=1686
  _QUERYTOTALTIMEOUTFEESRESPONSE._serialized_end=1816
  _QUERYPAYEEREQUEST._serialized_start=1818
  _QUERYPAYEEREQUEST._serialized_end=1874
  _QUERYPAYEERESPONSE._serialized_start=1876
  _QUERYPAYEERESPONSE._serialized_end=1919
  _QUERYCOUNTERPARTYPAYEEREQUEST._serialized_start=1921
  _QUERYCOUNTERPARTYPAYEEREQUEST._serialized_end=1989
  _QUERYCOUNTERPARTYPAYEERESPONSE._serialized_start=1991
  _QUERYCOUNTERPARTYPAYEERESPONSE._serialized_end=2051
  _QUERYFEEENABLEDCHANNELSREQUEST._serialized_start=2053
  _QUERYFEEENABLEDCHANNELSREQUEST._serialized_end=2167
  _QUERYFEEENABLEDCHANNELSRESPONSE._serialized_start=2170
  _QUERYFEEENABLEDCHANNELSRESPONSE._serialized_end=2344
  _QUERYFEEENABLEDCHANNELREQUEST._serialized_start=2346
  _QUERYFEEENABLEDCHANNELREQUEST._serialized_end=2414
  _QUERYFEEENABLEDCHANNELRESPONSE._serialized_start=2416
  _QUERYFEEENABLEDCHANNELRESPONSE._serialized_end=2469
  _QUERY._serialized_start=2472
  _QUERY._serialized_end=4750
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/blocksync/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tendermint.types import block_pb2 as tendermint_dot_types_dot_block__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n tendermint/blocksync/types.proto\x12\x14tendermint.blocksync\x1a\x1ctendermint/types/block.proto\x1a\x1ctendermint/types/types.proto\"\x1e\n\x0c\x42lockRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\"!\n\x0fNoBlockResponse\x12\x0e\n\x06height\x18\x01 \x01(\x03\"m\n\rBlockResponse\x12&\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x17.tendermint.types.Block\x12\x34\n\next_commit\x18\x02 \x01(\x0b\x32 .tendermint.types.ExtendedCommit\"\x0f\n\rStatusRequest\".\n\x0eStatusResponse\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\x0c\n\x04\x62\x61se\x18\x02 \x01(\x03\"\xd0\x02\n\x07Message\x12;\n\rblock_request\x18\x01 \x01(\x0b\x32\".tendermint.blocksync.BlockRequestH\x00\x12\x42\n\x11no_block_response\x18\x02 \x01(\x0b\x32%.tendermint.blocksync.NoBlockResponseH\x00\x12=\n\x0e\x62lock_response\x18\x03 \x01(\x0b\x32#.tendermint.blocksync.BlockResponseH\x00\x12=\n\x0estatus_request\x18\x04 \x01(\x0b\x32#.tendermint.blocksync.StatusRequestH\x00\x12?\n\x0fstatus_response\x18\x05 \x01(\x0b\x32$.tendermint.blocksync.StatusResponseH\x00\x42\x05\n\x03sumB9Z7github.com/cometbft/cometbft/proto/tendermint/blocksyncb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.blocksync.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/cometbft/cometbft/proto/tendermint/blocksync'
  _BLOCKREQUEST._serialized_start=118
  _BLOCKREQUEST._serialized_end=148
  _NOBLOCKRESPONSE._serialized_start=150
  _NOBLOCKRESPONSE._serialized_end=183
  _BLOCKRESPONSE._serialized_start=185
  _BLOCKRESPONSE._serialized_end=294
  _STATUSREQUEST._serialized_start=296
  _STATUSREQUEST._serialized_end=311
  _STATUSRESPONSE._serialized_start=313
  _STATUSRESPONSE._serialized_end=359
  _MESSAGE._serialized_start=362
  _MESSAGE._serialized_end=698
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from cosmos.authz.v1beta1 import query_pb2 as cosmos_dot_authz_dot_v1beta1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Grants = channel.unary_unary(
                '/cosmos.authz.v1beta1.Query/Grants',
                request_serializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGrantsRequest.SerializeToString,
                response_deserializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGrantsResponse.FromString,
                )
        self.GranterGrants = channel.unary_unary(
                '/cosmos.authz.v1beta1.Query/GranterGrants',
                request_serializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranterGrantsRequest.SerializeToString,
                response_deserializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranterGrantsResponse.FromString,
                )
        self.GranteeGrants = channel.unary_unary(
                '/cosmos.authz.v1beta1.Query/GranteeGrants',
                request_serializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranteeGrantsRequest.SerializeToString,
                response_deserializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranteeGrantsResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Grants(self, request, context):
        """Returns list of `Authorization`, granted to the grantee by the granter.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GranterGrants(self, request, context):
        """GranterGrants returns list of `GrantAuthorization`, granted by granter.

        Since: cosmos-sdk 0.46
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GranteeGrants(self, request, context):
        """GranteeGrants returns a list of `GrantAuthorization` by grantee.

        Since: cosmos-sdk 0.46
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Grants': grpc.unary_unary_rpc_method_handler(
                    servicer.Grants,
                    request_deserializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGrantsRequest.FromString,
                    response_serializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGrantsResponse.SerializeToString,
            ),
            'GranterGrants': grpc.unary_unary_rpc_method_handler(
                    servicer.GranterGrants,
                    request_deserializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranterGrantsRequest.FromString,
                    response_serializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranterGrantsResponse.SerializeToString,
            ),
            'GranteeGrants': grpc.unary_unary_rpc_method_handler(
                    servicer.GranteeGrants,
                    request_deserializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranteeGrantsRequest.FromString,
                    response_serializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranteeGrantsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.authz.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Grants(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.authz.v1beta1.Query/Grants',
            cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGrantsRequest.SerializeToString,
            cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGrantsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GranterGrants(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.authz.v1beta1.Query/GranterGrants',
            cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranterGrantsRequest.SerializeToString,
            cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranterGrantsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GranteeGrants(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.authz.v1beta1.Query/GranteeGrants',
            cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranteeGrantsRequest.SerializeToString,
            cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranteeGrantsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/lightclients/solomachine/v2/solomachine.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ibc.core.connection.v1 import connection_pb2 as ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2
from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1ibc/lightclients/solomachine/v2/solomachine.proto\x12\x1fibc.lightclients.solomachine.v2\x1a\'ibc/core/connection/v1/connection.proto\x1a!ibc/core/channel/v1/channel.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"\xa7\x01\n\x0b\x43lientState\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x11\n\tis_frozen\x18\x02 \x01(\x08\x12H\n\x0f\x63onsensus_state\x18\x03 \x01(\x0b\x32/.ibc.lightclients.solomachine.v2.ConsensusState\x12#\n\x1b\x61llow_update_after_proposal\x18\x04 \x01(\x08:\x04\x88\xa0\x1f\x00\"h\n\x0e\x43onsensusState\x12(\n\npublic_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x13\n\x0b\x64iversifier\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x04:\x04\x88\xa0\x1f\x00\"\x8d\x01\n\x06Header\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x11\n\tsignature\x18\x03 \x01(\x0c\x12,\n\x0enew_public_key\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x17\n\x0fnew_diversifier\x18\x05 \x01(\t:\x04\x88\xa0\x1f\x00\"\xcd\x01\n\x0cMisbehaviour\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x10\n\x08sequence\x18\x02 \x01(\x04\x12H\n\rsignature_one\x18\x03 \x01(\x0b\x32\x31.ibc.lightclients.solomachine.v2.SignatureAndData\x12H\n\rsignature_two\x18\x04 \x01(\x0b\x32\x31.ibc.lightclients.solomachine.v2.SignatureAndData:\x04\x88\xa0\x1f\x00\"\x8a\x01\n\x10SignatureAndData\x12\x11\n\tsignature\x18\x01 \x01(\x0c\x12<\n\tdata_type\x18\x02 \x01(\x0e\x32).ibc.lightclients.solomachine.v2.DataType\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x11\n\ttimestamp\x18\x04 \x01(\x04:\x04\x88\xa0\x1f\x00\"K\n\x18TimestampedSignatureData\x12\x16\n\x0esignature_data\x18\x01 \x01(\x0c\x12\x11\n\ttimestamp\x18\x02 \x01(\x04:\x04\x88\xa0\x1f\x00\"\x97\x01\n\tSignBytes\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x13\n\x0b\x64iversifier\x18\x03 \x01(\t\x12<\n\tdata_type\x18\x04 \x01(\x0e\x32).ibc.lightclients.solomachine.v2.DataType\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c:\x04\x88\xa0\x1f\x00\"V\n\nHeaderData\x12)\n\x0bnew_pub_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x17\n\x0fnew_diversifier\x18\x02 \x01(\t:\x04\x88\xa0\x1f\x00\"Q\n\x0f\x43lientStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12*\n\x0c\x63lient_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x04\x88\xa0\x1f\x00\"W\n\x12\x43onsensusStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12-\n\x0f\x63onsensus_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x04\x88\xa0\x1f\x00\"d\n\x13\x43onnectionStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x39\n\nconnection\x18\x02 \x01(\x0b\x32%.ibc.core.connection.v1.ConnectionEnd:\x04\x88\xa0\x1f\x00\"U\n\x10\x43hannelStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12-\n\x07\x63hannel\x18\x02 \x01(\x0b\x32\x1c.ibc.core.channel.v1.Channel:\x04\x88\xa0\x1f\x00\"8\n\x14PacketCommitmentData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x12\n\ncommitment\x18\x02 \x01(\x0c\"B\n\x19PacketAcknowledgementData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x17\n\x0f\x61\x63knowledgement\x18\x02 \x01(\x0c\"(\n\x18PacketReceiptAbsenceData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\";\n\x14NextSequenceRecvData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x15\n\rnext_seq_recv\x18\x02 \x01(\x04*\x8c\x04\n\x08\x44\x61taType\x12\x38\n#DATA_TYPE_UNINITIALIZED_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUNSPECIFIED\x12&\n\x16\x44\x41TA_TYPE_CLIENT_STATE\x10\x01\x1a\n\x8a\x9d \x06\x43LIENT\x12,\n\x19\x44\x41TA_TYPE_CONSENSUS_STATE\x10\x02\x1a\r\x8a\x9d \tCONSENSUS\x12.\n\x1a\x44\x41TA_TYPE_CONNECTION_STATE\x10\x03\x1a\x0e\x8a\x9d \nCONNECTION\x12(\n\x17\x44\x41TA_TYPE_CHANNEL_STATE\x10\x04\x1a\x0b\x8a\x9d \x07\x43HANNEL\x12\x35\n\x1b\x44\x41TA_TYPE_PACKET_COMMITMENT\x10\x05\x1a\x14\x8a\x9d \x10PACKETCOMMITMENT\x12?\n DATA_TYPE_PACKET_ACKNOWLEDGEMENT\x10\x06\x1a\x19\x8a\x9d \x15PACKETACKNOWLEDGEMENT\x12>\n DATA_TYPE_PACKET_RECEIPT_ABSENCE\x10\x07\x1a\x18\x8a\x9d \x14PACKETRECEIPTABSENCE\x12\x36\n\x1c\x44\x41TA_TYPE_NEXT_SEQUENCE_RECV\x10\x08\x1a\x14\x8a\x9d \x10NEXTSEQUENCERECV\x12 \n\x10\x44\x41TA_TYPE_HEADER\x10\t\x1a\n\x8a\x9d \x06HEADER\x1a\x04\x88\xa3\x1e\x00\x42\x42Z@github.com/cosmos/ibc-go/v7/modules/core/02-client/migrations/v7b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.lightclients.solomachine.v2.solomachine_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z@github.com/cosmos/ibc-go/v7/modules/core/02-client/migrations/v7'
  _DATATYPE._options = None
  _DATATYPE._serialized_options = b'\210\243\036\000'
  _DATATYPE.values_by_name["DATA_TYPE_UNINITIALIZED_UNSPECIFIED"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_UNINITIALIZED_UNSPECIFIED"]._serialized_options = b'\212\235 \013UNSPECIFIED'
  _DATATYPE.values_by_name["DATA_TYPE_CLIENT_STATE"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_CLIENT_STATE"]._serialized_options = b'\212\235 \006CLIENT'
  _DATATYPE.values_by_name["DATA_TYPE_CONSENSUS_STATE"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_CONSENSUS_STATE"]._serialized_options = b'\212\235 \tCONSENSUS'
  _DATATYPE.values_by_name["DATA_TYPE_CONNECTION_STATE"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_CONNECTION_STATE"]._serialized_options = b'\212\235 \nCONNECTION'
  _DATATYPE.values_by_name["DATA_TYPE_CHANNEL_STATE"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_CHANNEL_STATE"]._serialized_options = b'\212\235 \007CHANNEL'
  _DATATYPE.values_by_name["DATA_TYPE_PACKET_COMMITMENT"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_PACKET_COMMITMENT"]._serialized_options = b'\212\235 \020PACKETCOMMITMENT'
  _DATATYPE.values_by_name["DATA_TYPE_PACKET_ACKNOWLEDGEMENT"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_PACKET_ACKNOWLEDGEMENT"]._serialized_options = b'\212\235 \025PACKETACKNOWLEDGEMENT'
  _DATATYPE.values_by_name["DATA_TYPE_PACKET_RECEIPT_ABSENCE"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_PACKET_RECEIPT_ABSENCE"]._serialized_options = b'\212\235 \024PACKETRECEIPTABSENCE'
  _DATATYPE.values_by_name["DATA_TYPE_NEXT_SEQUENCE_RECV"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_NEXT_SEQUENCE_RECV"]._serialized_options = b'\212\235 \020NEXTSEQUENCERECV'
  _DATATYPE.values_by_name["DATA_TYPE_HEADER"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_HEADER"]._serialized_options = b'\212\235 \006HEADER'
  _CLIENTSTATE._options = None
  _CLIENTSTATE._serialized_options = b'\210\240\037\000'
  _CONSENSUSSTATE._options = None
  _CONSENSUSSTATE._serialized_options = b'\210\240\037\000'
  _HEADER._options = None
  _HEADER._serialized_options = b'\210\240\037\000'
  _MISBEHAVIOUR._options = None
  _MISBEHAVIOUR._serialized_options = b'\210\240\037\000'
  _SIGNATUREANDDATA._options = None
  _SIGNATUREANDDATA._serialized_options = b'\210\240\037\000'
  _TIMESTAMPEDSIGNATUREDATA._options = None
  _TIMESTAMPEDSIGNATUREDATA._serialized_options = b'\210\240\037\000'
  _SIGNBYTES._options = None
  _SIGNBYTES._serialized_options = b'\210\240\037\000'
  _HEADERDATA._options = None
  _HEADERDATA._serialized_options = b'\210\240\037\000'
  _CLIENTSTATEDATA._options = None
  _CLIENTSTATEDATA._serialized_options = b'\210\240\037\000'
  _CONSENSUSSTATEDATA._options = None
  _CONSENSUSSTATEDATA._serialized_options = b'\210\240\037\000'
  _CONNECTIONSTATEDATA._options = None
  _CONNECTIONSTATEDATA._serialized_options = b'\210\240\037\000'
  _CHANNELSTATEDATA._options = None
  _CHANNELSTATEDATA._serialized_options = b'\210\240\037\000'
  _DATATYPE._serialized_start=1890
  _DATATYPE._serialized_end=2414
  _CLIENTSTATE._serialized_start=212
  _CLIENTSTATE._serialized_end=379
  _CONSENSUSSTATE._serialized_start=381
  _CONSENSUSSTATE._serialized_end=485
  _HEADER._serialized_start=488
  _HEADER._serialized_end=629
  _MISBEHAVIOUR._serialized_start=632
  _MISBEHAVIOUR._serialized_end=837
  _SIGNATUREANDDATA._serialized_start=840
  _SIGNATUREANDDATA._serialized_end=978
  _TIMESTAMPEDSIGNATUREDATA._serialized_start=980
  _TIMESTAMPEDSIGNATUREDATA._serialized_end=1055
  _SIGNBYTES._serialized_start=1058
  _SIGNBYTES._serialized_end=1209
  _HEADERDATA._serialized_start=1211
  _HEADERDATA._serialized_end=1297
  _CLIENTSTATEDATA._serialized_start=1299
  _CLIENTSTATEDATA._serialized_end=1380
  _CONSENSUSSTATEDATA._serialized_start=1382
  _CONSENSUSSTATEDATA._serialized_end=1469
  _CONNECTIONSTATEDATA._serialized_start=1471
  _CONNECTIONSTATEDATA._serialized_end=1571
  _CHANNELSTATEDATA._serialized_start=1573
  _CHANNELSTATEDATA._serialized_end=1658
  _PACKETCOMMITMENTDATA._serialized_start=1660
  _PACKETCOMMITMENTDATA._serialized_end=1716
  _PACKETACKNOWLEDGEMENTDATA._serialized_start=1718
  _PACKETACKNOWLEDGEMENTDATA._serialized_end=1784
  _PACKETRECEIPTABSENCEDATA._serialized_start=1786
  _PACKETRECEIPTABSENCEDATA._serialized_end=1826
  _NEXTSEQUENCERECVDATA._serialized_start=1828
  _NEXTSEQUENCERECVDATA._serialized_end=1887
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/transfer/v1/transfer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ibc/applications/transfer/v1/transfer.proto\x12\x1cibc.applications.transfer.v1\".\n\nDenomTrace\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x12\n\nbase_denom\x18\x02 \x01(\t\"7\n\x06Params\x12\x14\n\x0csend_enabled\x18\x01 \x01(\x08\x12\x17\n\x0freceive_enabled\x18\x02 \x01(\x08\x42\x39Z7github.com/cosmos/ibc-go/v7/modules/apps/transfer/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.transfer.v1.transfer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/cosmos/ibc-go/v7/modules/apps/transfer/types'
  _DENOMTRACE._serialized_start=77
  _DENOMTRACE._serialized_end=123
  _PARAMS._serialized_start=125
  _PARAMS._serialized_end=180
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/params/module/v1/module.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/params/module/v1/module.proto\x12\x17\x63osmos.params.module.v1\x1a cosmos/app/v1alpha1/module.proto\"7\n\x06Module:-\xba\xc0\x96\xda\x01\'\n%github.com/cosmos/cosmos-sdk/x/paramsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.params.module.v1.module_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MODULE._options = None
  _MODULE._serialized_options = b'\272\300\226\332\001\'\n%github.com/cosmos/cosmos-sdk/x/params'
  _MODULE._serialized_start=99
  _MODULE._serialized_end=154
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/consensus/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from tendermint.types import params_pb2 as tendermint_dot_types_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmos/consensus/v1/tx.proto\x12\x13\x63osmos.consensus.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x1dtendermint/types/params.proto\"\xe6\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12,\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x1d.tendermint.types.BlockParams\x12\x32\n\x08\x65vidence\x18\x03 \x01(\x0b\x32 .tendermint.types.EvidenceParams\x12\x34\n\tvalidator\x18\x04 \x01(\x0b\x32!.tendermint.types.ValidatorParams:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse2i\n\x03Msg\x12\x62\n\x0cUpdateParams\x12$.cosmos.consensus.v1.MsgUpdateParams\x1a,.cosmos.consensus.v1.MsgUpdateParamsResponseB0Z.github.com/cosmos/cosmos-sdk/x/consensus/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.consensus.v1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z.github.com/cosmos/cosmos-sdk/x/consensus/types'
  _MSGUPDATEPARAMS.fields_by_name['authority']._options = None
  _MSGUPDATEPARAMS.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority'
  _MSGUPDATEPARAMS._serialized_start=137
  _MSGUPDATEPARAMS._serialized_end=367
  _MSGUPDATEPARAMSRESPONSE._serialized_start=369
  _MSGUPDATEPARAMSRESPONSE._serialized_end=394
  _MSG._serialized_start=396
  _MSG._serialized_end=501
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/vesting/v1beta1/vesting.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.auth.v1beta1 import auth_pb2 as cosmos_dot_auth_dot_v1beta1_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/vesting/v1beta1/vesting.proto\x12\x16\x63osmos.vesting.v1beta1\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/auth/v1beta1/auth.proto\"\xd3\x03\n\x12\x42\x61seVestingAccount\x12<\n\x0c\x62\x61se_account\x18\x01 \x01(\x0b\x32 .cosmos.auth.v1beta1.BaseAccountB\x04\xd0\xde\x1f\x01\x12j\n\x10original_vesting\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12h\n\x0e\x64\x65legated_free\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12k\n\x11\x64\x65legated_vesting\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x10\n\x08\x65nd_time\x18\x05 \x01(\x03:*\x8a\xe7\xb0*\x1d\x63osmos-sdk/BaseVestingAccount\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"\xb0\x01\n\x18\x43ontinuousVestingAccount\x12N\n\x14\x62\x61se_vesting_account\x18\x01 \x01(\x0b\x32*.cosmos.vesting.v1beta1.BaseVestingAccountB\x04\xd0\xde\x1f\x01\x12\x12\n\nstart_time\x18\x02 \x01(\x03:0\x8a\xe7\xb0*#cosmos-sdk/ContinuousVestingAccount\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"\x96\x01\n\x15\x44\x65layedVestingAccount\x12N\n\x14\x62\x61se_vesting_account\x18\x01 \x01(\x0b\x32*.cosmos.vesting.v1beta1.BaseVestingAccountB\x04\xd0\xde\x1f\x01:-\x8a\xe7\xb0* cosmos-sdk/DelayedVestingAccount\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"\x80\x01\n\x06Period\x12\x0e\n\x06length\x18\x01 \x01(\x03\x12`\n\x06\x61mount\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x04\x98\xa0\x1f\x00\"\xf0\x01\n\x16PeriodicVestingAccount\x12N\n\x14\x62\x61se_vesting_account\x18\x01 \x01(\x0b\x32*.cosmos.vesting.v1beta1.BaseVestingAccountB\x04\xd0\xde\x1f\x01\x12\x12\n\nstart_time\x18\x02 \x01(\x03\x12\x42\n\x0fvesting_periods\x18\x03 \x03(\x0b\x32\x1e.cosmos.vesting.v1beta1.PeriodB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:.\x8a\xe7\xb0*!cosmos-sdk/PeriodicVestingAccount\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"\x98\x01\n\x16PermanentLockedAccount\x12N\n\x14\x62\x61se_vesting_account\x18\x01 \x01(\x0b\x32*.cosmos.vesting.v1beta1.BaseVestingAccountB\x04\xd0\xde\x1f\x01:.\x8a\xe7\xb0*!cosmos-sdk/PermanentLockedAccount\x88\xa0\x1f\x00\x98\xa0\x1f\x00\x42\x33Z1github.com/cosmos/cosmos-sdk/x/auth/vesting/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.vesting.v1beta1.vesting_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/auth/vesting/types'
  _BASEVESTINGACCOUNT.fields_by_name['base_account']._options = None
  _BASEVESTINGACCOUNT.fields_by_name['base_account']._serialized_options = b'\320\336\037\001'
  _BASEVESTINGACCOUNT.fields_by_name['original_vesting']._options = None
  _BASEVESTINGACCOUNT.fields_by_name['original_vesting']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _BASEVESTINGACCOUNT.fields_by_name['delegated_free']._options = None
  _BASEVESTINGACCOUNT.fields_by_name['delegated_free']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _BASEVESTINGACCOUNT.fields_by_name['delegated_vesting']._options = None
  _BASEVESTINGACCOUNT.fields_by_name['delegated_vesting']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _BASEVESTINGACCOUNT._options = None
  _BASEVESTINGACCOUNT._serialized_options = b'\212\347\260*\035cosmos-sdk/BaseVestingAccount\210\240\037\000\230\240\037\000'
  _CONTINUOUSVESTINGACCOUNT.fields_by_name['base_vesting_account']._options = None
  _CONTINUOUSVESTINGACCOUNT.fields_by_name['base_vesting_account']._serialized_options = b'\320\336\037\001'
  _CONTINUOUSVESTINGACCOUNT._options = None
  _CONTINUOUSVESTINGACCOUNT._serialized_options = b'\212\347\260*#cosmos-sdk/ContinuousVestingAccount\210\240\037\000\230\240\037\000'
  _DELAYEDVESTINGACCOUNT.fields_by_name['base_vesting_account']._options = None
  _DELAYEDVESTINGACCOUNT.fields_by_name['base_vesting_account']._serialized_options = b'\320\336\037\001'
  _DELAYEDVESTINGACCOUNT._options = None
  _DELAYEDVESTINGACCOUNT._serialized_options = b'\212\347\260* cosmos-sdk/DelayedVestingAccount\210\240\037\000\230\240\037\000'
  _PERIOD.fields_by_name['amount']._options = None
  _PERIOD.fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _PERIOD._options = None
  _PERIOD._serialized_options = b'\230\240\037\000'
  _PERIODICVESTINGACCOUNT.fields_by_name['base_vesting_account']._options = None
  _PERIODICVESTINGACCOUNT.fields_by_name['base_vesting_account']._serialized_options = b'\320\336\037\001'
  _PERIODICVESTINGACCOUNT.fields_by_name['vesting_periods']._options = None
  _PERIODICVESTINGACCOUNT.fields_by_name['vesting_periods']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _PERIODICVESTINGACCOUNT._options = None
  _PERIODICVESTINGACCOUNT._serialized_options = b'\212\347\260*!cosmos-sdk/PeriodicVestingAccount\210\240\037\000\230\240\037\000'
  _PERMANENTLOCKEDACCOUNT.fields_by_name['base_vesting_account']._options = None
  _PERMANENTLOCKEDACCOUNT.fields_by_name['base_vesting_account']._serialized_options = b'\320\336\037\001'
  _PERMANENTLOCKEDACCOUNT._options = None
  _PERMANENTLOCKEDACCOUNT._serialized_options = b'\212\347\260*!cosmos-sdk/PermanentLockedAccount\210\240\037\000\230\240\037\000'
  _BASEVESTINGACCOUNT._serialized_start=170
  _BASEVESTINGACCOUNT._serialized_end=637
  _CONTINUOUSVESTINGACCOUNT._serialized_start=640
  _CONTINUOUSVESTINGACCOUNT._serialized_end=816
  _DELAYEDVESTINGACCOUNT._serialized_start=819
  _DELAYEDVESTINGACCOUNT._serialized_end=969
  _PERIOD._serialized_start=972
  _PERIOD._serialized_end=1100
  _PERIODICVESTINGACCOUNT._serialized_start=1103
  _PERIODICVESTINGACCOUNT._serialized_end=1343
  _PERMANENTLOCKEDACCOUNT._serialized_start=1346
  _PERMANENTLOCKEDACCOUNT._serialized_end=1498
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmwasm/wasm/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmwasm.wasm.v1 import types_pb2 as cosmwasm_dot_wasm_dot_v1_dot_types__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x63osmwasm/wasm/v1/tx.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a\x1c\x63osmwasm/wasm/v1/types.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\xb7\x01\n\x0cMsgStoreCode\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12(\n\x0ewasm_byte_code\x18\x02 \x01(\x0c\x42\x10\xe2\xde\x1f\x0cWASMByteCode\x12>\n\x16instantiate_permission\x18\x05 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfig:!\x8a\xe7\xb0*\x11wasm/MsgStoreCode\x82\xe7\xb0*\x06senderJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"E\n\x14MsgStoreCodeResponse\x12\x1b\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\x10\n\x08\x63hecksum\x18\x02 \x01(\x0c\"\x96\x02\n\x16MsgInstantiateContract\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\r\n\x05\x61\x64min\x18\x02 \x01(\t\x12\x1b\n\x07\x63ode_id\x18\x03 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\r\n\x05label\x18\x04 \x01(\t\x12#\n\x03msg\x18\x05 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\x12_\n\x05\x66unds\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:+\x8a\xe7\xb0*\x1bwasm/MsgInstantiateContract\x82\xe7\xb0*\x06sender\"?\n\x1eMsgInstantiateContractResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\xb7\x02\n\x17MsgInstantiateContract2\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\r\n\x05\x61\x64min\x18\x02 \x01(\t\x12\x1b\n\x07\x63ode_id\x18\x03 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\r\n\x05label\x18\x04 \x01(\t\x12#\n\x03msg\x18\x05 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\x12_\n\x05\x66unds\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x0c\n\x04salt\x18\x07 \x01(\x0c\x12\x0f\n\x07\x66ix_msg\x18\x08 \x01(\x08:,\x8a\xe7\xb0*\x1cwasm/MsgInstantiateContract2\x82\xe7\xb0*\x06sender\"@\n\x1fMsgInstantiateContract2Response\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\xe5\x01\n\x12MsgExecuteContract\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08\x63ontract\x18\x02 \x01(\t\x12#\n\x03msg\x18\x03 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\x12_\n\x05\x66unds\x18\x05 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\'\x8a\xe7\xb0*\x17wasm/MsgExecuteContract\x82\xe7\xb0*\x06sender\"*\n\x1aMsgExecuteContractResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\xa1\x01\n\x12MsgMigrateContract\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08\x63ontract\x18\x02 \x01(\t\x12\x1b\n\x07\x63ode_id\x18\x03 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12#\n\x03msg\x18\x04 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage:\'\x8a\xe7\xb0*\x17wasm/MsgMigrateContract\x82\xe7\xb0*\x06sender\"*\n\x1aMsgMigrateContractResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"j\n\x0eMsgUpdateAdmin\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tnew_admin\x18\x02 \x01(\t\x12\x10\n\x08\x63ontract\x18\x03 \x01(\t:#\x8a\xe7\xb0*\x13wasm/MsgUpdateAdmin\x82\xe7\xb0*\x06sender\"\x18\n\x16MsgUpdateAdminResponse\"U\n\rMsgClearAdmin\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08\x63ontract\x18\x03 \x01(\t:\"\x8a\xe7\xb0*\x12wasm/MsgClearAdmin\x82\xe7\xb0*\x06sender\"\x17\n\x15MsgClearAdminResponse\"\xbe\x01\n\x1aMsgUpdateInstantiateConfig\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x1b\n\x07\x63ode_id\x18\x02 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\x42\n\x1anew_instantiate_permission\x18\x03 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfig:/\x8a\xe7\xb0*\x1fwasm/MsgUpdateInstantiateConfig\x82\xe7\xb0*\x06sender\"$\n\"MsgUpdateInstantiateConfigResponse\"\x9c\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x06params\x18\x02 \x01(\x0b\x32\x18.cosmwasm.wasm.v1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:\'\x8a\xe7\xb0*\x14wasm/MsgUpdateParams\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse\"\x9e\x01\n\x0fMsgSudoContract\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x10\n\x08\x63ontract\x18\x02 \x01(\t\x12#\n\x03msg\x18\x03 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage:\'\x8a\xe7\xb0*\x14wasm/MsgSudoContract\x82\xe7\xb0*\tauthority\"\'\n\x17MsgSudoContractResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x91\x01\n\x0bMsgPinCodes\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x30\n\x08\x63ode_ids\x18\x02 \x03(\x04\x42\x1e\xe2\xde\x1f\x07\x43odeIDs\xf2\xde\x1f\x0fyaml:\"code_ids\":#\x8a\xe7\xb0*\x10wasm/MsgPinCodes\x82\xe7\xb0*\tauthority\"\x15\n\x13MsgPinCodesResponse\"\x95\x01\n\rMsgUnpinCodes\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x30\n\x08\x63ode_ids\x18\x02 \x03(\x04\x42\x1e\xe2\xde\x1f\x07\x43odeIDs\xf2\xde\x1f\x0fyaml:\"code_ids\":%\x8a\xe7\xb0*\x12wasm/MsgUnpinCodes\x82\xe7\xb0*\tauthority\"\x17\n\x15MsgUnpinCodesResponse\"\xdb\x03\n\x1eMsgStoreAndInstantiateContract\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12(\n\x0ewasm_byte_code\x18\x03 \x01(\x0c\x42\x10\xe2\xde\x1f\x0cWASMByteCode\x12>\n\x16instantiate_permission\x18\x04 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfig\x12\x12\n\nunpin_code\x18\x05 \x01(\x08\x12\r\n\x05\x61\x64min\x18\x06 \x01(\t\x12\r\n\x05label\x18\x07 \x01(\t\x12#\n\x03msg\x18\x08 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\x12_\n\x05\x66unds\x18\t \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x0e\n\x06source\x18\n \x01(\t\x12\x0f\n\x07\x62uilder\x18\x0b \x01(\t\x12\x11\n\tcode_hash\x18\x0c \x01(\x0c:6\x8a\xe7\xb0*#wasm/MsgStoreAndInstantiateContract\x82\xe7\xb0*\tauthority\"G\n&MsgStoreAndInstantiateContractResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x32\xb5\n\n\x03Msg\x12S\n\tStoreCode\x12\x1e.cosmwasm.wasm.v1.MsgStoreCode\x1a&.cosmwasm.wasm.v1.MsgStoreCodeResponse\x12q\n\x13InstantiateContract\x12(.cosmwasm.wasm.v1.MsgInstantiateContract\x1a\x30.cosmwasm.wasm.v1.MsgInstantiateContractResponse\x12t\n\x14InstantiateContract2\x12).cosmwasm.wasm.v1.MsgInstantiateContract2\x1a\x31.cosmwasm.wasm.v1.MsgInstantiateContract2Response\x12\x65\n\x0f\x45xecuteContract\x12$.cosmwasm.wasm.v1.MsgExecuteContract\x1a,.cosmwasm.wasm.v1.MsgExecuteContractResponse\x12\x65\n\x0fMigrateContract\x12$.cosmwasm.wasm.v1.MsgMigrateContract\x1a,.cosmwasm.wasm.v1.MsgMigrateContractResponse\x12Y\n\x0bUpdateAdmin\x12 .cosmwasm.wasm.v1.MsgUpdateAdmin\x1a(.cosmwasm.wasm.v1.MsgUpdateAdminResponse\x12V\n\nClearAdmin\x12\x1f.cosmwasm.wasm.v1.MsgClearAdmin\x1a\'.cosmwasm.wasm.v1.MsgClearAdminResponse\x12}\n\x17UpdateInstantiateConfig\x12,.cosmwasm.wasm.v1.MsgUpdateInstantiateConfig\x1a\x34.cosmwasm.wasm.v1.MsgUpdateInstantiateConfigResponse\x12\\\n\x0cUpdateParams\x12!.cosmwasm.wasm.v1.MsgUpdateParams\x1a).cosmwasm.wasm.v1.MsgUpdateParamsResponse\x12\\\n\x0cSudoContract\x12!.cosmwasm.wasm.v1.MsgSudoContract\x1a).cosmwasm.wasm.v1.MsgSudoContractResponse\x12P\n\x08PinCodes\x12\x1d.cosmwasm.wasm.v1.MsgPinCodes\x1a%.cosmwasm.wasm.v1.MsgPinCodesResponse\x12V\n\nUnpinCodes\x12\x1f.cosmwasm.wasm.v1.MsgUnpinCodes\x1a\'.cosmwasm.wasm.v1.MsgUnpinCodesResponse\x12\x89\x01\n\x1bStoreAndInstantiateContract\x12\x30.cosmwasm.wasm.v1.MsgStoreAndInstantiateContract\x1a\x38.cosmwasm.wasm.v1.MsgStoreAndInstantiateContractResponseB,Z&github.com/CosmWasm/wasmd/x/wasm/types\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmwasm.wasm.v1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z&github.com/CosmWasm/wasmd/x/wasm/types\310\341\036\000'
  _MSGSTORECODE.fields_by_name['wasm_byte_code']._options = None
  _MSGSTORECODE.fields_by_name['wasm_byte_code']._serialized_options = b'\342\336\037\014WASMByteCode'
  _MSGSTORECODE._options = None
  _MSGSTORECODE._serialized_options = b'\212\347\260*\021wasm/MsgStoreCode\202\347\260*\006sender'
  _MSGSTORECODERESPONSE.fields_by_name['code_id']._options = None
  _MSGSTORECODERESPONSE.fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _MSGINSTANTIATECONTRACT.fields_by_name['code_id']._options = None
  _MSGINSTANTIATECONTRACT.fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _MSGINSTANTIATECONTRACT.fields_by_name['msg']._options = None
  _MSGINSTANTIATECONTRACT.fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _MSGINSTANTIATECONTRACT.fields_by_name['funds']._options = None
  _MSGINSTANTIATECONTRACT.fields_by_name['funds']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGINSTANTIATECONTRACT._options = None
  _MSGINSTANTIATECONTRACT._serialized_options = b'\212\347\260*\033wasm/MsgInstantiateContract\202\347\260*\006sender'
  _MSGINSTANTIATECONTRACT2.fields_by_name['code_id']._options = None
  _MSGINSTANTIATECONTRACT2.fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _MSGINSTANTIATECONTRACT2.fields_by_name['msg']._options = None
  _MSGINSTANTIATECONTRACT2.fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _MSGINSTANTIATECONTRACT2.fields_by_name['funds']._options = None
  _MSGINSTANTIATECONTRACT2.fields_by_name['funds']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGINSTANTIATECONTRACT2._options = None
  _MSGINSTANTIATECONTRACT2._serialized_options = b'\212\347\260*\034wasm/MsgInstantiateContract2\202\347\260*\006sender'
  _MSGEXECUTECONTRACT.fields_by_name['msg']._options = None
  _MSGEXECUTECONTRACT.fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _MSGEXECUTECONTRACT.fields_by_name['funds']._options = None
  _MSGEXECUTECONTRACT.fields_by_name['funds']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGEXECUTECONTRACT._options = None
  _MSGEXECUTECONTRACT._serialized_options = b'\212\347\260*\027wasm/MsgExecuteContract\202\347\260*\006sender'
  _MSGMIGRATECONTRACT.fields_by_name['code_id']._options = None
  _MSGMIGRATECONTRACT.fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _MSGMIGRATECONTRACT.fields_by_name['msg']._options = None
  _MSGMIGRATECONTRACT.fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _MSGMIGRATECONTRACT._options = None
  _MSGMIGRATECONTRACT._serialized_options = b'\212\347\260*\027wasm/MsgMigrateContract\202\347\260*\006sender'
  _MSGUPDATEADMIN._options = None
  _MSGUPDATEADMIN._serialized_options = b'\212\347\260*\023wasm/MsgUpdateAdmin\202\347\260*\006sender'
  _MSGCLEARADMIN._options = None
  _MSGCLEARADMIN._serialized_options = b'\212\347\260*\022wasm/MsgClearAdmin\202\347\260*\006sender'
  _MSGUPDATEINSTANTIATECONFIG.fields_by_name['code_id']._options = None
  _MSGUPDATEINSTANTIATECONFIG.fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _MSGUPDATEINSTANTIATECONFIG._options = None
  _MSGUPDATEINSTANTIATECONFIG._serialized_options = b'\212\347\260*\037wasm/MsgUpdateInstantiateConfig\202\347\260*\006sender'
  _MSGUPDATEPARAMS.fields_by_name['authority']._options = None
  _MSGUPDATEPARAMS.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\212\347\260*\024wasm/MsgUpdateParams\202\347\260*\tauthority'
  _MSGSUDOCONTRACT.fields_by_name['authority']._options = None
  _MSGSUDOCONTRACT.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGSUDOCONTRACT.fields_by_name['msg']._options = None
  _MSGSUDOCONTRACT.fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _MSGSUDOCONTRACT._options = None
  _MSGSUDOCONTRACT._serialized_options = b'\212\347\260*\024wasm/MsgSudoContract\202\347\260*\tauthority'
  _MSGPINCODES.fields_by_name['authority']._options = None
  _MSGPINCODES.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGPINCODES.fields_by_name['code_ids']._options = None
  _MSGPINCODES.fields_by_name['code_ids']._serialized_options = b'\342\336\037\007CodeIDs\362\336\037\017yaml:\"code_ids\"'
  _MSGPINCODES._options = None
  _MSGPINCODES._serialized_options = b'\212\347\260*\020wasm/MsgPinCodes\202\347\260*\tauthority'
  _MSGUNPINCODES.fields_by_name['authority']._options = None
  _MSGUNPINCODES.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUNPINCODES.fields_by_name['code_ids']._options = None
  _MSGUNPINCODES.fields_by_name['code_ids']._serialized_options = b'\342\336\037\007CodeIDs\362\336\037\017yaml:\"code_ids\"'
  _MSGUNPINCODES._options = None
  _MSGUNPINCODES._serialized_options = b'\212\347\260*\022wasm/MsgUnpinCodes\202\347\260*\tauthority'
  _MSGSTOREANDINSTANTIATECONTRACT.fields_by_name['authority']._options = None
  _MSGSTOREANDINSTANTIATECONTRACT.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGSTOREANDINSTANTIATECONTRACT.fields_by_name['wasm_byte_code']._options = None
  _MSGSTOREANDINSTANTIATECONTRACT.fields_by_name['wasm_byte_code']._serialized_options = b'\342\336\037\014WASMByteCode'
  _MSGSTOREANDINSTANTIATECONTRACT.fields_by_name['msg']._options = None
  _MSGSTOREANDINSTANTIATECONTRACT.fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _MSGSTOREANDINSTANTIATECONTRACT.fields_by_name['funds']._options = None
  _MSGSTOREANDINSTANTIATECONTRACT.fields_by_name['funds']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGSTOREANDINSTANTIATECONTRACT._options = None
  _MSGSTOREANDINSTANTIATECONTRACT._serialized_options = b'\212\347\260*#wasm/MsgStoreAndInstantiateContract\202\347\260*\tauthority'
  _MSGSTORECODE._serialized_start=203
  _MSGSTORECODE._serialized_end=386
  _MSGSTORECODERESPONSE._serialized_start=388
  _MSGSTORECODERESPONSE._serialized_end=457
  _MSGINSTANTIATECONTRACT._serialized_start=460
  _MSGINSTANTIATECONTRACT._serialized_end=738
  _MSGINSTANTIATECONTRACTRESPONSE._serialized_start=740
  _MSGINSTANTIATECONTRACTRESPONSE._serialized_end=803
  _MSGINSTANTIATECONTRACT2._serialized_start=806
  _MSGINSTANTIATECONTRACT2._serialized_end=1117
  _MSGINSTANTIATECONTRACT2RESPONSE._serialized_start=1119
  _MSGINSTANTIATECONTRACT2RESPONSE._serialized_end=1183
  _MSGEXECUTECONTRACT._serialized_start=1186
  _MSGEXECUTECONTRACT._serialized_end=1415
  _MSGEXECUTECONTRACTRESPONSE._serialized_start=1417
  _MSGEXECUTECONTRACTRESPONSE._serialized_end=1459
  _MSGMIGRATECONTRACT._serialized_start=1462
  _MSGMIGRATECONTRACT._serialized_end=1623
  _MSGMIGRATECONTRACTRESPONSE._serialized_start=1625
  _MSGMIGRATECONTRACTRESPONSE._serialized_end=1667
  _MSGUPDATEADMIN._serialized_start=1669
  _MSGUPDATEADMIN._serialized_end=1775
  _MSGUPDATEADMINRESPONSE._serialized_start=1777
  _MSGUPDATEADMINRESPONSE._serialized_end=1801
  _MSGCLEARADMIN._serialized_start=1803
  _MSGCLEARADMIN._serialized_end=1888
  _MSGCLEARADMINRESPONSE._serialized_start=1890
  _MSGCLEARADMINRESPONSE._serialized_end=1913
  _MSGUPDATEINSTANTIATECONFIG._serialized_start=1916
  _MSGUPDATEINSTANTIATECONFIG._serialized_end=2106
  _MSGUPDATEINSTANTIATECONFIGRESPONSE._serialized_start=2108
  _MSGUPDATEINSTANTIATECONFIGRESPONSE._serialized_end=2144
  _MSGUPDATEPARAMS._serialized_start=2147
  _MSGUPDATEPARAMS._serialized_end=2303
  _MSGUPDATEPARAMSRESPONSE._serialized_start=2305
  _MSGUPDATEPARAMSRESPONSE._serialized_end=2330
  _MSGSUDOCONTRACT._serialized_start=2333
  _MSGSUDOCONTRACT._serialized_end=2491
  _MSGSUDOCONTRACTRESPONSE._serialized_start=2493
  _MSGSUDOCONTRACTRESPONSE._serialized_end=2532
  _MSGPINCODES._serialized_start=2535
  _MSGPINCODES._serialized_end=2680
  _MSGPINCODESRESPONSE._serialized_start=2682
  _MSGPINCODESRESPONSE._serialized_end=2703
  _MSGUNPINCODES._serialized_start=2706
  _MSGUNPINCODES._serialized_end=2855
  _MSGUNPINCODESRESPONSE._serialized_start=2857
  _MSGUNPINCODESRESPONSE._serialized_end=2880
  _MSGSTOREANDINSTANTIATECONTRACT._serialized_start=2883
  _MSGSTOREANDINSTANTIATECONTRACT._serialized_end=3358
  _MSGSTOREANDINSTANTIATECONTRACTRESPONSE._serialized_start=3360
  _MSGSTOREANDINSTANTIATECONTRACTRESPONSE._serialized_end=3431
  _MSG._serialized_start=3434
  _MSG._serialized_end=4767
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/fee/v1/metadata.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ibc/applications/fee/v1/metadata.proto\x12\x17ibc.applications.fee.v1\"4\n\x08Metadata\x12\x13\n\x0b\x66\x65\x65_version\x18\x01 \x01(\t\x12\x13\n\x0b\x61pp_version\x18\x02 \x01(\tB7Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.fee.v1.metadata_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/types'
  _METADATA._serialized_start=67
  _METADATA._serialized_end=119
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/transfer/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from ibc.applications.transfer.v1 import transfer_pb2 as ibc_dot_applications_dot_transfer_dot_v1_dot_transfer__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ibc/applications/transfer/v1/tx.proto\x12\x1cibc.applications.transfer.v1\x1a\x14gogoproto/gogo.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1fibc/core/client/v1/client.proto\x1a+ibc/applications/transfer/v1/transfer.proto\"\x84\x02\n\x0bMsgTransfer\x12\x13\n\x0bsource_port\x18\x01 \x01(\t\x12\x16\n\x0esource_channel\x18\x02 \x01(\t\x12.\n\x05token\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06sender\x18\x04 \x01(\t\x12\x10\n\x08receiver\x18\x05 \x01(\t\x12\x38\n\x0etimeout_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x19\n\x11timeout_timestamp\x18\x07 \x01(\x04\x12\x0c\n\x04memo\x18\x08 \x01(\t:\x13\x82\xe7\xb0*\x06sender\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\'\n\x13MsgTransferResponse\x12\x10\n\x08sequence\x18\x01 \x01(\x04\"p\n\x0fMsgUpdateParams\x12\x11\n\tauthority\x18\x01 \x01(\t\x12:\n\x06params\x18\x02 \x01(\x0b\x32$.ibc.applications.transfer.v1.ParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse2\xec\x01\n\x03Msg\x12h\n\x08Transfer\x12).ibc.applications.transfer.v1.MsgTransfer\x1a\x31.ibc.applications.transfer.v1.MsgTransferResponse\x12t\n\x0cUpdateParams\x12-.ibc.applications.transfer.v1.MsgUpdateParams\x1a\x35.ibc.applications.transfer.v1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x39Z7github.com/cosmos/ibc-go/v7/modules/apps/transfer/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.transfer.v1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/cosmos/ibc-go/v7/modules/apps/transfer/types'
  _MSGTRANSFER.fields_by_name['token']._options = None
  _MSGTRANSFER.fields_by_name['token']._serialized_options = b'\310\336\037\000'
  _MSGTRANSFER.fields_by_name['timeout_height']._options = None
  _MSGTRANSFER.fields_by_name['timeout_height']._serialized_options = b'\310\336\037\000'
  _MSGTRANSFER._options = None
  _MSGTRANSFER._serialized_options = b'\202\347\260*\006sender\350\240\037\000\210\240\037\000'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _MSGTRANSFER._serialized_start=229
  _MSGTRANSFER._serialized_end=489
  _MSGTRANSFERRESPONSE._serialized_start=491
  _MSGTRANSFERRESPONSE._serialized_end=530
  _MSGUPDATEPARAMS._serialized_start=532
  _MSGUPDATEPARAMS._serialized_end=644
  _MSGUPDATEPARAMSRESPONSE._serialized_start=646
  _MSGUPDATEPARAMSRESPONSE._serialized_end=671
  _MSG._serialized_start=674
  _MSG._serialized_end=910
# @@protoc_insertion_point(module_scope)



from eth_hash.auto import keccak

from pyinjective import PrivateKey, Address


class TestPrivateKey:

    def test_private_key_signature_generation(self):
        private_key = PrivateKey.from_mnemonic("test mnemonic never use other places")

        signature = private_key.sign(msg="test message".encode())
        expected_signature = b'\x8f\xae\xcb#z\x9a+\x12\x88\xea\xb5xZ"\x8f\x98y\xb8\x97\xa7F\xd5\xdd\x15s\x05;\x04\x1d\xbaY|rw\x8b\xbb\x19\xfc\x8e\x15\x8b\xf1\x18\x08\xba\xc7\x15\xed\xb0\xee\x95\x0e|Ch\x7f\xaf\x9cH\xc6\x9f\xbf\x14\xa5'

        assert (expected_signature == signature)


class TestPublicKey:

    def test_convert_public_key_to_address(self):
        private_key = PrivateKey.from_mnemonic("test mnemonic never use other places")
        public_key = private_key.to_public_key()
        address = public_key.to_address()

        key = public_key.verify_key.to_string("uncompressed")
        hashed_value = keccak(key[1:])
        expected_address = Address(hashed_value[12:])

        assert (expected_address == address)




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/query/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63osmos/query/v1/query.proto\x12\x0f\x63osmos.query.v1\x1a google/protobuf/descriptor.proto:<\n\x11module_query_safe\x12\x1e.google.protobuf.MethodOptions\x18\xf1\x8c\xa6\x05 \x01(\x08\x42*Z(github.com/cosmos/cosmos-sdk/types/queryb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.query.v1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(module_query_safe)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z(github.com/cosmos/cosmos-sdk/types/query'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/fee/v1/ack.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ibc/applications/fee/v1/ack.proto\x12\x17ibc.applications.fee.v1\"{\n\x1bIncentivizedAcknowledgement\x12\x1b\n\x13\x61pp_acknowledgement\x18\x01 \x01(\x0c\x12\x1f\n\x17\x66orward_relayer_address\x18\x02 \x01(\t\x12\x1e\n\x16underlying_app_success\x18\x03 \x01(\x08\x42\x37Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.fee.v1.ack_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/types'
  _INCENTIVIZEDACKNOWLEDGEMENT._serialized_start=62
  _INCENTIVIZEDACKNOWLEDGEMENT._serialized_end=185
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/interchain_accounts/controller/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.applications.interchain_accounts.v1 import packet_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_v1_dot_packet__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;ibc/applications/interchain_accounts/controller/v1/tx.proto\x12\x32ibc.applications.interchain_accounts.controller.v1\x1a\x14gogoproto/gogo.proto\x1a\x34ibc/applications/interchain_accounts/v1/packet.proto\x1a\x17\x63osmos/msg/v1/msg.proto\"i\n\x1cMsgRegisterInterchainAccount\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x15\n\rconnection_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t:\x12\x82\xe7\xb0*\x05owner\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"K\n$MsgRegisterInterchainAccountResponse\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\x0f\n\x07port_id\x18\x02 \x01(\t\"\xc0\x01\n\tMsgSendTx\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x15\n\rconnection_id\x18\x02 \x01(\t\x12_\n\x0bpacket_data\x18\x03 \x01(\x0b\x32\x44.ibc.applications.interchain_accounts.v1.InterchainAccountPacketDataB\x04\xc8\xde\x1f\x00\x12\x18\n\x10relative_timeout\x18\x04 \x01(\x04:\x12\x82\xe7\xb0*\x05owner\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"%\n\x11MsgSendTxResponse\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x32\xe7\x02\n\x03Msg\x12\xc7\x01\n\x19RegisterInterchainAccount\x12P.ibc.applications.interchain_accounts.controller.v1.MsgRegisterInterchainAccount\x1aX.ibc.applications.interchain_accounts.controller.v1.MsgRegisterInterchainAccountResponse\x12\x8e\x01\n\x06SendTx\x12=.ibc.applications.interchain_accounts.controller.v1.MsgSendTx\x1a\x45.ibc.applications.interchain_accounts.controller.v1.MsgSendTxResponse\x1a\x05\x80\xe7\xb0*\x01\x42RZPgithub.com/cosmos/ibc-go/v7/modules/apps/27-interchain-accounts/controller/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.controller.v1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/cosmos/ibc-go/v7/modules/apps/27-interchain-accounts/controller/types'
  _MSGREGISTERINTERCHAINACCOUNT._options = None
  _MSGREGISTERINTERCHAINACCOUNT._serialized_options = b'\202\347\260*\005owner\350\240\037\000\210\240\037\000'
  _MSGSENDTX.fields_by_name['packet_data']._options = None
  _MSGSENDTX.fields_by_name['packet_data']._serialized_options = b'\310\336\037\000'
  _MSGSENDTX._options = None
  _MSGSENDTX._serialized_options = b'\202\347\260*\005owner\350\240\037\000\210\240\037\000'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _MSGREGISTERINTERCHAINACCOUNT._serialized_start=216
  _MSGREGISTERINTERCHAINACCOUNT._serialized_end=321
  _MSGREGISTERINTERCHAINACCOUNTRESPONSE._serialized_start=323
  _MSGREGISTERINTERCHAINACCOUNTRESPONSE._serialized_end=398
  _MSGSENDTX._serialized_start=401
  _MSGSENDTX._serialized_end=593
  _MSGSENDTXRESPONSE._serialized_start=595
  _MSGSENDTXRESPONSE._serialized_end=632
  _MSG._serialized_start=635
  _MSG._serialized_end=994
# @@protoc_insertion_point(module_scope)
